define('Purch/UI/Zoom', ['jquery'], function($) {

    "use strict";

    var Zoom = function(options) {
        this.options = $.extend({
            targets: ':not(a) > .imgContent :not([href]).iZoom img[big-src]',
            containerClass: 'img-zoom-container',
            innerClass: 'img-zoom-sub',
            imgClass: 'img-zoom',
            bigAttr: 'big-src',
            init: true,
            closeOnScroll: true,
            closeControl: false,
            fullSize: false,
            startOnInit: false
        }, options || {});

        this.win = window;

        if (this.options.init === true) {
            this.init();
        }
    };

    Zoom.prototype = {
        init: function() {
            var self = this;
            var body = $('body');

            this.checkZooms();

            //Binding on init
            if(self.options.startOnInit === true){
                $(this.options.targets).each(function(){
                    self.addElements($(this));
                });
            }
            //Delegate binding on mouseenter
            body.on('mouseenter', this.options.targets, function () {
                self.addElements($(this));
            });

            body.on('click', '.' + self.options.innerClass, function () {
                var $el = $(this).prev('img');
                var closeControl = $el.data('options-closecontrol') === true ? true : self.options.closeControl;
                if (!closeControl) {
                    $('.' + self.options.containerClass).blur();
                }
            });

            if (self.options.closeOnScroll) {
                $(this.win).on('scroll', function () {
                        self.blur();
                });
            }


            $(this.win).on('keyup', function(e) {
                if(e.keyCode === 27) {
                    self.blur();
                }
            });
        },

        checkZooms: function() {
            $(this.options.targets).closest('.iZoom').addClass('img-zoom-in');
        },

        addElements: function($el) {
            var self = this;

            if ($el.hasClass('z-loaded')) {
                $el.off('mouseenter');
                return false;
            }
            $el.addClass('z-loaded');
            var containerId = this.getRandom();
            var i = 3 + $el.index(this.options.targets);

            var closeControl = $el.data('options-closecontrol') === true ? true : self.options.closeControl;
            var fullSize = $el.data('options-fullsize') === true ? true : self.options.fullSize;

            var container = $('<div />', {
                id: containerId,
                tabindex: i,
                'class': this.options.containerClass + (fullSize === true ? ' img-zoom-fullsize' : '')
            });
            var img = $('<img>', {
                src: $el.attr(this.options.bigAttr),
                'class': this.options.imgClass
            });
            var inner = $('<div />', {
                id: containerId + '-' + i,
                'class': this.options.innerClass
            });

            $el.wrap(container).after(inner.append(img));

            if(closeControl){
              self.addCloseElement($el);
            }

            if(fullSize || closeControl){
                var wrapper =   $('<div />', {
                    'class': this.options.imgClass + '-wrap'
                });
                var $container = $el.parent('.' + self.options.containerClass);
                $container.find('.' + self.options.imgClass).wrap(wrapper);
            }
            return true;
        },

        addCloseElement: function($el) {
            var self = this;
            var $container = $el.parent('.' + self.options.containerClass);

            var $close = $('<span />', {
                'class': 'img-zoom-close-ctrl'
            });

            $container.find('.' + self.options.innerClass).prepend($close);
            $container.addClass('img-zoom-with-close');

            $close.on('click', function(){
                self.blur();
            });
        },

        blur:function(){
           $('.' + this.options.containerClass).blur();
        },

        getRandom: function() {
            return Math.round(new Date().getTime() + (Math.random() * 100));
        }
    };

    Zoom.initModule = function(options) {
        return new Zoom(options || {});
    };

    return Zoom;
});